Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2517)

Unified Diff: chrome/browser/ui/webui/plugins_ui.cc

Issue 893823002: Register system Pepper Flash plugin if no packaged Pepper plugin is found. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: address comments. read location of pepperflash from registry. Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/component_updater/test/component_installers_unittest.cc ('k') | chrome/chrome_browser.gypi » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/webui/plugins_ui.cc
diff --git a/chrome/browser/ui/webui/plugins_ui.cc b/chrome/browser/ui/webui/plugins_ui.cc
index 09afd464022c7ec3c22285faa978055c472ea6af..42249028b55036db3c3688a9732c5e527e652029 100644
--- a/chrome/browser/ui/webui/plugins_ui.cc
+++ b/chrome/browser/ui/webui/plugins_ui.cc
@@ -372,16 +372,24 @@ void PluginsDOMHandler::PluginsLoaded(
plugin_file->SetString("name", group_plugin.name);
// If this plugin is Pepper Flash, and the plugin path is the same as the
// path for the Pepper Flash Debugger plugin, then mark this plugin
// description as the debugger plugin to help the user disambiguate the
// two plugins.
base::string16 desc = group_plugin.desc;
if (group_plugin.is_pepper_plugin() &&
group_plugin.name == base::ASCIIToUTF16(content::kFlashPluginName)) {
- base::FilePath debug_path;
- PathService::Get(chrome::DIR_PEPPER_FLASH_DEBUGGER_PLUGIN, &debug_path);
- if (group_plugin.path.DirName() == debug_path)
+ base::FilePath system_path;
+ PathService::Get(chrome::DIR_PEPPER_FLASH_SYSTEM_PLUGIN, &system_path);
+ if (group_plugin.path.DirName() == system_path) {
+#if defined(GOOGLE_CHROME_BUILD)
+ // Existing documentation for debugging Flash describe this plugin as
+ // "Debug" so preserve this nomenclature here.
desc += base::ASCIIToUTF16(" Debug");
+#else
+ // On Chromium, we can name it what it really is; the system plugin.
+ desc += base::ASCIIToUTF16(" System");
+#endif
+ }
}
plugin_file->SetString("description", desc);
« no previous file with comments | « chrome/browser/component_updater/test/component_installers_unittest.cc ('k') | chrome/chrome_browser.gypi » ('j') | no next file with comments »
@@ -372,16 +372,24 @@ void PluginsDOMHandler::PluginsLoaded(
plugin_file->SetString("name", group_plugin.name);
// If this plugin is Pepper Flash, and the plugin path is the same as the
- // path for the Pepper Flash Debugger plugin, then mark this plugin
- // description as the debugger plugin to help the user disambiguate the
+ // path for the Pepper Flash System plugin, then mark this plugin
+ // description as the system plugin to help the user disambiguate the
// two plugins.
base::string16 desc = group_plugin.desc;

Powered by Google App Engine
This is Rietveld 408576698